[![PyPI](https://img.shields.io/pypi/v/omemo-backend-signal.svg)](https://pypi.org/project/omemo-backend-signal/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/omemo-backend-signal.svg)](https://pypi.org/project/omemo-backend-signal/)

# python-omemo-backend-signal
#### A backend for python-omemo offering compatibility with libsignal.

This library implements a backend for [python-omemo](https://github.com/Syndace/python-omemo) offering compatibility with libsignal ([C](https://github.com/signalapp/libsignal-protocol-c), [Java](https://github.com/signalapp/libsignal-protocol-java), [JavaScript](https://github.com/signalapp/libsignal-protocol-javascript)). Look at [python-omemo](https://github.com/Syndace/python-omemo) for further usage information.

NOTE: This repository contains a compiled version of a [protobuf](https://developers.google.com/protocol-buffers/) structure definition file. The Makefile can be used to reproduce the compilation step. This might require version 2.* of the protobuf compiler (not 3 or later).
